==> qtjambi-activex-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiActiveX/QAxWidget_shell.h <==
#ifndef QAXWIDGET_SHELL_H
#define QAXWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxwidget.h>)
#include <ActiveQt/qaxwidget.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qaction.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxWidget_shell : public QAxWidget, public QtJambiShellInterface
{
public:
    QAxWidget_shell(const QString& c0, QWidget* parent1 = nullptr, Qt::WindowFlags f2 = Qt::WindowFlags());
    QAxWidget_shell(QWidget* parent0 = nullptr, Qt::WindowFlags f1 = Qt::WindowFlags());
    ~QAxWidget_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* e0) override;
    void childEvent(QChildEvent* event0) override;
    const char* className() const override;
    void clear() override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    bool createHostWindow(bool arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    const QMetaObject* fallbackMetaObject() const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    bool propertyWritable(const char* arg__1) const override;
    QObject* qObject() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool translateKeyEvent(int message0, int keycode1) const override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__className_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxWidget_access : public QAxWidget
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_createHostWindow_bool_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arg__1, QtJambiNativeID arg__2);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jstring __qt_className(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
    jboolean __qt_createHostWindow_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arg__1);
    jobject __qt_fallbackMetaObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_minimumSizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    jobject __qt_qObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
    jobject __qt_sizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_translateKeyEvent_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint message0, jint keycode1) const;
};

#endif // defined(Q_OS_WIN)
#endif // QAXWIDGET_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiActiveX/QAxWidget_shell.h <==
#ifndef QAXWIDGET_SHELL_H
#define QAXWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxwidget.h>)
#include <ActiveQt/qaxwidget.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qaction.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxWidget_shell : public QAxWidget, public QtJambiShellInterface
{
public:
    QAxWidget_shell(const QString& c0, QWidget* parent1 = nullptr, Qt::WindowFlags f2 = Qt::WindowFlags());
    QAxWidget_shell(QWidget* parent0 = nullptr, Qt::WindowFlags f1 = Qt::WindowFlags());
    ~QAxWidget_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* e0) override;
    void childEvent(QChildEvent* event0) override;
    const char* className() const override;
    void clear() override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    bool createHostWindow(bool arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    const QMetaObject* fallbackMetaObject() const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    bool propertyWritable(const char* arg__1) const override;
    QObject* qObject() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool translateKeyEvent(int message0, int keycode1) const override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__className_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxWidget_access : public QAxWidget
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_createHostWindow_bool_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arg__1, QtJambiNativeID arg__2);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jstring __qt_className_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
    jboolean __qt_createHostWindow_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arg__1);
    jobject __qt_fallbackMetaObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_minimumSizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    jobject __qt_qObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_translateKeyEvent_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint message0, jint keycode1) const;
};

#endif // defined(Q_OS_WIN)
#endif // QAXWIDGET_SHELL_H
